@@ -4,10 +4,11 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use overload
   '""'     => sub { shift->to_string },
+  bool     => sub { 1 },
   fallback => 1;
 
 use Carp qw(croak);
@@ -221,7 +222,7 @@ Returns the block in canonical form.
   say Net::IPAM::Block->new('1.2.3.4-1.2.3.36')->to_string;   # 1.2.3.4-1.2.3.36
   say Net::IPAM::Block->new('127.0.0.1')->to_string;          # 127.0.0.1/32
 
-Stringification is overloaded with C<to_string>
+Stringification is overloaded with L</"to_string">
 
   my $b = Net::IPAM::Block->new('fe80::/10');
   say $b;                                      # fe80::/10
@@ -505,11 +506,11 @@ not so obvious for ranges:
 =cut
 
 sub bitlen {
-	my $self = shift;
+  my $self = shift;
   my $bits = 32;
   $bits = 128 if $self->version == 6;
 
-  return _bitlen($self->{base}->bytes, $self->{last}->bytes, $bits);
+  return _bitlen( $self->{base}->bytes, $self->{last}->bytes, $bits );
 }
 
 =head2 iter
@@ -730,7 +731,7 @@ sub find_free_cidrs {
   my @free;
 
   # start with outer block, split them to find free cidrs
-  my @candidates = ($outer->to_cidrs);
+  my @candidates = ( $outer->to_cidrs );
 
   while (@candidates) {
     my $this = shift @candidates;
@@ -942,6 +943,22 @@ sub aggregate {
   return wantarray ? @cidrs : [@cidrs];
 }
 
+=head1 OPERATORS
+
+L<Net::IPAM::Block> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$block;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$block";
+
+Alias for L</"to_string">.
+
 =head1 AUTHOR
 
 Karl Gaissmaier, C<< <karl.gaissmaier(at)uni-ulm.de> >>
